<?php

namespace Drupal\erf\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller for Registration edit forms.
 *
 * @ingroup erf
 */
class RegistrationForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    // Change the 'Save' submit button label.
    $form['actions']['submit']['#value'] = $this->t($this->entity->isNew() ? 'Register' : 'Update Registration');

    // If this registration form is embedded in another entity, hide the delete
    // action.
    if ($form_state->getBuildInfo()['callback_object']->getOperation() === 'embedded') {
      $form['actions']['delete']['#access'] = FALSE;
    }

    // Configure the cache settings so that anonymous users don't see each
    // others registration form data.
    $form['#cache']['contexts'][] = 'session';
    $form['#cache']['tags'][] = 'registration_list';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $entity = $this->entity;

    $status = parent::save($form, $form_state);

    switch ($status) {
      case SAVED_NEW:
        drupal_set_message($this->t('Registration created.'));
        break;

      default:
        drupal_set_message($this->t('Registration saved.'));
    }
  }

}
