<?php

namespace Drupal\erf;

use Drupal\Core\Form\FormStateInterface;

class IefDuplicateParticipantConstraint {

  /**
   * Custom validation callback for participant inline entity forms.
   *
   * @see erf_inline_entity_form_entity_form_alter().
   */
  public static function validate(array &$entity_form, FormStateInterface $form_state) {
    $current_participant = $entity_form['#entity'];
    $build_info = $form_state->getBuildInfo();
    $registration = $build_info['callback_object']->getEntity();
    $other_participant_emails = [];

    // These are the participants that are 'collapsed' in the inline entity form.
    foreach ($registration->participants->referencedEntities() as $participant) {
      $other_participant_emails[] = $participant->mail->value;
    }

    if (in_array($current_participant->mail->value, $other_participant_emails)) {
      $triggering_element = $form_state->getTriggeringElement();
      $message = t('A participant with %email already exists for this registration!!!', [
        '%email' => $current_participant->mail->value,
      ]);
      $form_state->setError($triggering_element, $message);
    }
  }

}
